@@ -20,7 +20,12 @@ def importPBN(pbn):
     tags, sections, notes = parsePBN(pbn)
     # try to fetch lead
     if "Play" in sections:
-        tags["Lead"] = sections["Play"].split()[0]
+        # it could be empty or ""
+        playlist = sections["Play"].split()
+        if len(playlist):
+            tags["Lead"] = sections["Play"].split()[0]
+        else:
+            tags["Lead"] = ""
     else:
         tags["Lead"] = ""
     if "Event" not in tags:
