@@ -108,7 +108,7 @@ def get_xinruiurl(file):
     print(">> found %d xinrui url" % len(urls))
     return urls
 
-def check_file(file, generate_all=True):
+def check_file(file):
     dir=os.path.dirname(file)
     filename = os.path.splitext(os.path.basename(file))[0]
     urls = get_xinruiurl(file)
@@ -123,19 +123,18 @@ def check_file(file, generate_all=True):
             pbn_file=os.path.join(dir,"%s-%02d.pbn" % (filename, index + 1))
             with open(pbn_file, 'rb') as readfile:
                 shutil.copyfileobj(readfile, outfile)
-    if generate_all==False:
-        # remove files
-        for index, url in enumerate(urls):
-            pbn_file=os.path.join(dir,"%s-%02d" % (filename, index + 1))
-            print("remove temple file %s" % outfilename)
-            if os.path.isfile(pbn_file):
-                os.remove(pbn_file)
+    # remove files
+    for index, url in enumerate(urls):
+        pbn_file=os.path.join(dir,"%s-%02d.pbn" % (filename, index + 1))
+        print("remove temple file %s" % pbn_file)
+        if os.path.isfile(pbn_file):
+            os.remove(pbn_file)
 
-def generate_pbn_from_html(html_files, generate_all=True):
+def generate_pbn_from_html(html_files):
     print(">> checking %s" % html_files)
     for file in html_files:
         if file.endswith(".html") or file.endswith(".htm"):
-            check_file(file, generate_all)
+            check_file(file)
 
 def main():
     # print(sys.argv)
